Diofant
=======

A Python library for symbolic mathematics.

For `installation instructions`_ and usage information,
see the `online documentation`_.

`New BSD License`_ covers all files in this repository unless stated otherwise.

.. _online documentation: https://diofant.readthedocs.io/en/latest/
.. _installation instructions: https://diofant.readthedocs.io/en/latest/install.html#installation
.. _New BSD License: https://github.com/diofant/diofant/blob/master/LICENSE
